==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/MetadataFileFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class MetadataFileFluentImpl<T extends MetadataFileFluent<T>> extends BaseFluent<T> implements MetadataFileFluent<T>{

     VisitableBuilder<ObjectFieldSelector, ?> fieldRef;     String name;     Map<String, Object> additionalProperties = new HashMap();

    public ObjectFieldSelector getFieldRef(){
    return this.fieldRef!=null?this.fieldRef.build():null;
    }
    public T withFieldRef( ObjectFieldSelector fieldRef){
    if (fieldRef!=null){ this.fieldRef= new ObjectFieldSelectorBuilder(fieldRef); _visitables.add(this.fieldRef);} return (T) this;
    }
    public FieldRefNested<T> withNewFieldRef(){
    return new FieldRefNestedImpl<T>();
    }
    public FieldRefNested<T> withNewFieldRefLike( ObjectFieldSelector item){
    return new FieldRefNestedImpl<T>(item);
    }
    public FieldRefNested<T> editFieldRef(){
    return withNewFieldRefLike(getFieldRef());
    }
    public T withNewFieldRef( String apiVersion,  String fieldPath){
    return withFieldRef(new ObjectFieldSelector(apiVersion, fieldPath));
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
MetadataFileFluentImpl that = (MetadataFileFluentImpl) o;
if (fieldRef != null ? !fieldRef.equals(that.fieldRef) :that.fieldRef != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FieldRefNestedImpl<N> extends ObjectFieldSelectorFluentImpl<FieldRefNested<N>> implements FieldRefNested<N>{

        private final ObjectFieldSelectorBuilder builder;
    
             FieldRefNestedImpl (){
        this.builder = new ObjectFieldSelectorBuilder(this);
        }
             FieldRefNestedImpl ( ObjectFieldSelector item){
        this.builder = new ObjectFieldSelectorBuilder(this, item);
        }
    
            public N and(){
            return (N) MetadataFileFluentImpl.this.withFieldRef(builder.build());
        }
            public N endFieldRef(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/MetadataFileFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class MetadataFileFluentImpl<A extends MetadataFileFluent<A>> extends BaseFluent<A> implements MetadataFileFluent<A>{

     VisitableBuilder<ObjectFieldSelector, ?> fieldRef;     String name;
public MetadataFileFluentImpl(){
    
}
public MetadataFileFluentImpl( MetadataFile instance ){
    this.withFieldRef(instance.getFieldRef()); this.withName(instance.getName()); 
}

    public ObjectFieldSelector getFieldRef(){
    return this.fieldRef!=null?this.fieldRef.build():null;
    }
    public A withFieldRef( ObjectFieldSelector fieldRef){
    if (fieldRef!=null){ this.fieldRef= new ObjectFieldSelectorBuilder(fieldRef); _visitables.add(this.fieldRef);} return (A) this;
    }
    public FieldRefNested<A> withNewFieldRef(){
    return new FieldRefNestedImpl();
    }
    public FieldRefNested<A> withNewFieldRefLike( ObjectFieldSelector item){
    return new FieldRefNestedImpl(item);
    }
    public FieldRefNested<A> editFieldRef(){
    return withNewFieldRefLike(getFieldRef());
    }
    public A withNewFieldRef( String apiVersion,  String fieldPath){
    return withFieldRef(new ObjectFieldSelector(apiVersion, fieldPath));
    }
    public String getName(){
    return this.name;
    }
    public A withName( String name){
    this.name=name; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
MetadataFileFluentImpl that = (MetadataFileFluentImpl) o;
if (fieldRef != null ? !fieldRef.equals(that.fieldRef) :that.fieldRef != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
return true;

    }

    public class FieldRefNestedImpl<N> extends ObjectFieldSelectorFluentImpl<FieldRefNested<N>> implements FieldRefNested<N>{

        private final ObjectFieldSelectorBuilder builder;
    
             FieldRefNestedImpl (){
        this.builder = new ObjectFieldSelectorBuilder(this);
        }
             FieldRefNestedImpl ( ObjectFieldSelector item){
        this.builder = new ObjectFieldSelectorBuilder(this, item);
        }
    
            public N and(){
            return (N) MetadataFileFluentImpl.this.withFieldRef(builder.build());
        }
            public N endFieldRef(){
            return and();
        }
    
}


}
